MethodChannelFlutterPdfAnnotations class

Method-channel implementation of FlutterPdfAnnotationsPlatform.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openPDF({required String filePath, String? savePath, PDFAnnotationConfig? config}) Future<PdfAnnotationResult>
Opens filePath in the native annotation editor.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited