locale property
Language for the editor UI.
When null the device locale is used, falling back to PdfLocale.english
if the device language is not supported.
Implementation
final PdfLocale? locale;
Language for the editor UI.
When null the device locale is used, falling back to PdfLocale.english
if the device language is not supported.
final PdfLocale? locale;