isCancelled property
bool
get
isCancelled
true when the user dismissed the editor without saving.
Implementation
bool get isCancelled => cancelled && savedPath == null && error == null;
true when the user dismissed the editor without saving.
bool get isCancelled => cancelled && savedPath == null && error == null;