PDFAnnotationConfig class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imagesToInsert
→ List<
Uint8List> ? -
Images that the user can stamp onto PDF pages.
final
- initialHighlightColor → Color?
-
Initial highlight colour.
final
- initialPage → int
-
Zero-based page index to open initially.
final
- initialPenColor → Color?
-
Initial pen colour. Include the desired alpha channel in the value.
final
- initialStrokeWidth → double?
-
Initial stroke width.
final
- locale → PdfLocale?
-
Language for the editor UI.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Title displayed in the editor's navigation bar.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serialises config fields to pass over the method channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited